# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
#
# Code generated by aaz-dev-tools
# --------------------------------------------------------------------------------------------

# pylint: skip-file
# flake8: noqa

from azure.cli.core.aaz import *


@register_command(
    "monitor activity-log list",
)
class List(AAZCommand):
    """List and query activity log events.

    :example: List all events from July 1st, looking forward one week.
        az monitor activity-log list --start-time 2018-07-01 --offset 7d

    :example: List events within the past six hours based on a correlation ID.
        az monitor activity-log list --correlation-id b5eac9d2-e829-4c9a-9efb-586d19417c5f

    :example: List events within the past hour based on resource group.
        az monitor activity-log list -g ResourceGroup --offset 1h
    """

    _aaz_info = {
        "version": "2015-04-01",
        "resources": [
            ["mgmt-plane", "/subscriptions/{}/providers/microsoft.insights/eventtypes/management/values", "2015-04-01"],
        ]
    }

    AZ_SUPPORT_PAGINATION = True

    def _handler(self, command_args):
        super()._handler(command_args)
        return self.build_paging(self._execute_operations, self._output)

    _args_schema = None

    @classmethod
    def _build_arguments_schema(cls, *args, **kwargs):
        if cls._args_schema is not None:
            return cls._args_schema
        cls._args_schema = super()._build_arguments_schema(*args, **kwargs)

        # define Arg Group ""

        _args_schema = cls._args_schema
        _args_schema.filter = AAZStrArg(
            options=["--filter"],
            help="Reduces the set of data collected.<br>This argument is required and it also requires at least the start date/time.<br>The **$filter** argument is very restricted and allows only the following patterns.<br>- *List events for a resource group*: $filter=eventTimestamp ge '2014-07-16T04:36:37.6407898Z' and eventTimestamp le '2014-07-20T04:36:37.6407898Z' and resourceGroupName eq 'resourceGroupName'.<br>- *List events for resource*: $filter=eventTimestamp ge '2014-07-16T04:36:37.6407898Z' and eventTimestamp le '2014-07-20T04:36:37.6407898Z' and resourceUri eq 'resourceURI'.<br>- *List events for a subscription in a time range*: $filter=eventTimestamp ge '2014-07-16T04:36:37.6407898Z' and eventTimestamp le '2014-07-20T04:36:37.6407898Z'.<br>- *List events for a resource provider*: $filter=eventTimestamp ge '2014-07-16T04:36:37.6407898Z' and eventTimestamp le '2014-07-20T04:36:37.6407898Z' and resourceProvider eq 'resourceProviderName'.<br>- *List events for a correlation Id*: $filter=eventTimestamp ge '2014-07-16T04:36:37.6407898Z' and eventTimestamp le '2014-07-20T04:36:37.6407898Z' and correlationId eq 'correlationID'.<br><br>**NOTE**: No other syntax is allowed.",
            required=True,
        )
        _args_schema.select = AAZStrArg(
            options=["--select"],
            help="Used to fetch events with only the given properties.<br>The **$select** argument is a comma separated list of property names to be returned. Possible values are: *authorization*, *claims*, *correlationId*, *description*, *eventDataId*, *eventName*, *eventTimestamp*, *httpRequest*, *level*, *operationId*, *operationName*, *properties*, *resourceGroupName*, *resourceProviderName*, *resourceId*, *status*, *submissionTimestamp*, *subStatus*, *subscriptionId*",
        )
        return cls._args_schema

    def _execute_operations(self):
        self.pre_operations()
        self.ActivityLogsList(ctx=self.ctx)()
        self.post_operations()

    @register_callback
    def pre_operations(self):
        pass

    @register_callback
    def post_operations(self):
        pass

    def _output(self, *args, **kwargs):
        result = self.deserialize_output(self.ctx.vars.instance.value, client_flatten=True)
        next_link = self.deserialize_output(self.ctx.vars.instance.next_link)
        return result, next_link

    class ActivityLogsList(AAZHttpOperation):
        CLIENT_TYPE = "MgmtClient"

        def __call__(self, *args, **kwargs):
            request = self.make_request()
            session = self.client.send_request(request=request, stream=False, **kwargs)
            if session.http_response.status_code in [200]:
                return self.on_200(session)

            return self.on_error(session.http_response)

        @property
        def url(self):
            return self.client.format_url(
                "/subscriptions/{subscriptionId}/providers/Microsoft.Insights/eventtypes/management/values",
                **self.url_parameters
            )

        @property
        def method(self):
            return "GET"

        @property
        def error_format(self):
            return "ODataV4Format"

        @property
        def url_parameters(self):
            parameters = {
                **self.serialize_url_param(
                    "subscriptionId", self.ctx.subscription_id,
                    required=True,
                ),
            }
            return parameters

        @property
        def query_parameters(self):
            parameters = {
                **self.serialize_query_param(
                    "$filter", self.ctx.args.filter,
                    required=True,
                ),
                **self.serialize_query_param(
                    "$select", self.ctx.args.select,
                ),
                **self.serialize_query_param(
                    "api-version", "2015-04-01",
                    required=True,
                ),
            }
            return parameters

        @property
        def header_parameters(self):
            parameters = {
                **self.serialize_header_param(
                    "Accept", "application/json",
                ),
            }
            return parameters

        def on_200(self, session):
            data = self.deserialize_http_content(session)
            self.ctx.set_var(
                "instance",
                data,
                schema_builder=self._build_schema_on_200
            )

        _schema_on_200 = None

        @classmethod
        def _build_schema_on_200(cls):
            if cls._schema_on_200 is not None:
                return cls._schema_on_200

            cls._schema_on_200 = AAZObjectType()

            _schema_on_200 = cls._schema_on_200
            _schema_on_200.next_link = AAZStrType(
                serialized_name="nextLink",
            )
            _schema_on_200.value = AAZListType(
                flags={"required": True},
            )

            value = cls._schema_on_200.value
            value.Element = AAZObjectType()

            _element = cls._schema_on_200.value.Element
            _element.authorization = AAZObjectType()
            _element.caller = AAZStrType(
                flags={"read_only": True},
            )
            _element.category = AAZObjectType()
            _ListHelper._build_schema_localizable_string_read(_element.category)
            _element.claims = AAZDictType(
                flags={"read_only": True},
            )
            _element.correlation_id = AAZStrType(
                serialized_name="correlationId",
                flags={"read_only": True},
            )
            _element.description = AAZStrType(
                flags={"read_only": True},
            )
            _element.event_data_id = AAZStrType(
                serialized_name="eventDataId",
                flags={"read_only": True},
            )
            _element.event_name = AAZObjectType(
                serialized_name="eventName",
            )
            _ListHelper._build_schema_localizable_string_read(_element.event_name)
            _element.event_timestamp = AAZStrType(
                serialized_name="eventTimestamp",
                flags={"read_only": True},
            )
            _element.http_request = AAZObjectType(
                serialized_name="httpRequest",
            )
            _element.id = AAZStrType(
                flags={"read_only": True},
            )
            _element.level = AAZStrType(
                flags={"read_only": True},
            )
            _element.operation_id = AAZStrType(
                serialized_name="operationId",
                flags={"read_only": True},
            )
            _element.operation_name = AAZObjectType(
                serialized_name="operationName",
            )
            _ListHelper._build_schema_localizable_string_read(_element.operation_name)
            _element.properties = AAZDictType(
                flags={"read_only": True},
            )
            _element.resource_group_name = AAZStrType(
                serialized_name="resourceGroupName",
                flags={"read_only": True},
            )
            _element.resource_id = AAZStrType(
                serialized_name="resourceId",
                flags={"read_only": True},
            )
            _element.resource_provider_name = AAZObjectType(
                serialized_name="resourceProviderName",
            )
            _element.resource_type = AAZObjectType(
                serialized_name="resourceType",
            )
            _element.status = AAZObjectType()
            _ListHelper._build_schema_localizable_string_read(_element.status)
            _element.sub_status = AAZObjectType(
                serialized_name="subStatus",
            )
            _ListHelper._build_schema_localizable_string_read(_element.sub_status)
            _element.submission_timestamp = AAZStrType(
                serialized_name="submissionTimestamp",
                flags={"read_only": True},
            )
            _element.subscription_id = AAZStrType(
                serialized_name="subscriptionId",
                flags={"read_only": True},
            )
            _element.tenant_id = AAZStrType(
                serialized_name="tenantId",
                flags={"read_only": True},
            )

            authorization = cls._schema_on_200.value.Element.authorization
            authorization.action = AAZStrType()
            authorization.role = AAZStrType()
            authorization.scope = AAZStrType()

            claims = cls._schema_on_200.value.Element.claims
            claims.Element = AAZStrType()

            http_request = cls._schema_on_200.value.Element.http_request
            http_request.client_ip_address = AAZStrType(
                serialized_name="clientIpAddress",
            )
            http_request.client_request_id = AAZStrType(
                serialized_name="clientRequestId",
            )
            http_request.method = AAZStrType()
            http_request.uri = AAZStrType()

            properties = cls._schema_on_200.value.Element.properties
            properties.Element = AAZStrType()

            resource_provider_name = cls._schema_on_200.value.Element.resource_provider_name
            resource_provider_name.localized_value = AAZStrType(
                serialized_name="localizedValue",
            )
            resource_provider_name.value = AAZStrType(
                flags={"required": True},
            )

            resource_type = cls._schema_on_200.value.Element.resource_type
            resource_type.localized_value = AAZStrType(
                serialized_name="localizedValue",
            )
            resource_type.value = AAZStrType(
                flags={"required": True},
            )

            return cls._schema_on_200


class _ListHelper:
    """Helper class for List"""

    _schema_localizable_string_read = None

    @classmethod
    def _build_schema_localizable_string_read(cls, _schema):
        if cls._schema_localizable_string_read is not None:
            _schema.localized_value = cls._schema_localizable_string_read.localized_value
            _schema.value = cls._schema_localizable_string_read.value
            return

        cls._schema_localizable_string_read = _schema_localizable_string_read = AAZObjectType()

        localizable_string_read = _schema_localizable_string_read
        localizable_string_read.localized_value = AAZStrType(
            serialized_name="localizedValue",
        )
        localizable_string_read.value = AAZStrType(
            flags={"required": True},
        )

        _schema.localized_value = cls._schema_localizable_string_read.localized_value
        _schema.value = cls._schema_localizable_string_read.value


__all__ = ["List"]



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

# pylint: disable=protected-access
# pylint: disable=too-few-public-methods
import argparse
from ._exception_handler import CLIError


class AttestationEvidenceAddAction(argparse._AppendAction):
    def __call__(self, parser, namespace, values, option_string=None):
        result = {}
        evidence = getattr(namespace, self.dest)
        if evidence is None:
            evidence = []
        for item in values:
            try:
                key, value = item.split('=', 1)
                result[key] = value
            except ValueError:
                raise CLIError('usage error: {} KEY=VALUE [KEY=VALUE ...] {} {} {}'
                               .format(option_string, item, result, evidence))
        evidence.append(result)
        setattr(namespace, self.dest, evidence)



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------


# pylint: disable=line-too-long
# pylint: disable=too-many-lines
# pylint: disable=inconsistent-return-statements
# pylint: disable=unused-variable
# pylint: disable=too-many-locals
# pylint: disable=too-many-return-statements

def add_network_rule_set_ip_rule(cmd, resource_group_name, namespace_name, ip_rule=None):
    from azure.cli.command_modules.servicebus.aaz.latest.servicebus.namespace.network_rule_set import Update
    from azure.cli.command_modules.servicebus.aaz.latest.servicebus.namespace.network_rule_set import Show
    from azure.cli.core import CLIError
    servicebus_ip_rule = Show(cli_ctx=cmd.cli_ctx)(command_args={
        "resource_group": resource_group_name,
        "namespace_name": namespace_name
    })
    ip_rule_list = []
    for i in servicebus_ip_rule["ipRules"]:
        ip_dict = {
            "ip_address": i["ipMask"],
            "action": i["action"]
        }
        ip_rule_list.append(ip_dict)
    for i in ip_rule:
        rule = {
            "ip_address": i["ip-address"],
            "action": i["action"]
        }
        if rule not in ip_rule_list:
            ip_rule_list.append(rule)
        else:
            raise CLIError('Duplicate Ip-rules Found.')
    command_args_dict = {
        "resource_group": resource_group_name,
        "namespace_name": namespace_name,
        "ip_rules": ip_rule_list
    }
    return Update(cli_ctx=cmd.cli_ctx)(command_args=command_args_dict)


def remove_network_rule_set_ip_rule(cmd, resource_group_name, namespace_name, ip_rule=None):
    from azure.cli.command_modules.servicebus.aaz.latest.servicebus.namespace.network_rule_set import Update
    from azure.cli.command_modules.servicebus.aaz.latest.servicebus.namespace.network_rule_set import Show
    servicebus_ip_rule = Show(cli_ctx=cmd.cli_ctx)(command_args={
        "resource_group": resource_group_name,
        "namespace_name": namespace_name
    })
    ip_rule_list = []
    for i in servicebus_ip_rule["ipRules"]:
        ip_rule_dict = {
            "ip_address": i["ipMask"],
            "action": i["action"]
        }
        ip_rule_list.append(ip_rule_dict)

    for i in ip_rule:
        for j in ip_rule_list[:]:
            if i['ip-address'] == j["ip_address"]:
                ip_rule_list.remove(j)
    command_args_dict = {
        "resource_group": resource_group_name,
        "namespace_name": namespace_name,
        "ip_rules": ip_rule_list
    }
    return Update(cli_ctx=cmd.cli_ctx)(command_args=command_args_dict)


def add_virtual_network_rule(cmd, resource_group_name, namespace_name, subnet=None):
    from azure.cli.command_modules.servicebus.aaz.latest.servicebus.namespace.network_rule_set import Update
    from azure.cli.command_modules.servicebus.aaz.latest.servicebus.namespace.network_rule_set import Show
    from azure.cli.core import CLIError
    servicebus_nw_rule = Show(cli_ctx=cmd.cli_ctx)(command_args={
        "resource_group": resource_group_name,
        "namespace_name": namespace_name
    })
    virtual_network_rule_list = []
    for i in servicebus_nw_rule["virtualNetworkRules"]:
        subnet_dict = {
            "subnet": i["subnet"]["id"],
            "ignore_missing_endpoint": i["ignoreMissingVnetServiceEndpoint"]
        }
        virtual_network_rule_list.append(subnet_dict)
    for i in subnet:
        rule = {
            "subnet": i["id"],
            "ignore_missing_endpoint": i["ignore_missing_endpoint"]
        }
        if rule not in virtual_network_rule_list:
            virtual_network_rule_list.append(rule)
        else:
            raise CLIError('Duplicate Subnet-rules Found.')
    command_args_dict = {
        "resource_group": resource_group_name,
        "namespace_name": namespace_name,
        "virtual_network_rules": virtual_network_rule_list
    }
    return Update(cli_ctx=cmd.cli_ctx)(command_args=command_args_dict)


def remove_virtual_network_rule(cmd, resource_group_name, namespace_name, subnet=None):

    from azure.cli.command_modules.servicebus.aaz.latest.servicebus.namespace.network_rule_set import Update
    from azure.cli.command_modules.servicebus.aaz.latest.servicebus.namespace.network_rule_set import Show
    servicebus_nw_rule = Show(cli_ctx=cmd.cli_ctx)(command_args={
        "resource_group": resource_group_name,
        "namespace_name": namespace_name
    })
    virtual_network_rule_list = []
    for i in servicebus_nw_rule["virtualNetworkRules"]:
        subnet_dict = {
            "subnet": i["subnet"]["id"],
            "ignore_missing_endpoint": i["ignoreMissingVnetServiceEndpoint"]
        }
        virtual_network_rule_list.append(subnet_dict)

    for i in subnet:
        for j in virtual_network_rule_list[:]:
            if i['id'].lower() == j['subnet'].lower():
                virtual_network_rule_list.remove(j)
    command_args_dict = {
        "resource_group": resource_group_name,
        "namespace_name": namespace_name,
        "virtual_network_rules": virtual_network_rule_list
    }
    return Update(cli_ctx=cmd.cli_ctx)(command_args=command_args_dict)



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from enum import Enum
from azure.core import CaseInsensitiveEnumMeta


class AccessMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Access mode for storage."""

    READ_ONLY = "ReadOnly"
    READ_WRITE = "ReadWrite"


class Action(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Allow or Deny rules to determine for incoming IP. Note: Rules can only consist of ALL Allow or
    ALL Deny.
    """

    ALLOW = "Allow"
    DENY = "Deny"


class ActiveRevisionsMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """ActiveRevisionsMode controls how active revisions are handled for the Container app:


    .. raw:: html

       <list><item>Multiple: multiple revisions can be active.</item><item>Single: Only one
    revision can be active at a time. Revision weights can not be used in this mode. If no value if
    provided, this is the default.</item></list>.
    """

    MULTIPLE = "Multiple"
    SINGLE = "Single"


class Affinity(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Sticky Session Affinity."""

    STICKY = "sticky"
    NONE = "none"


class Applicability(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """indicates whether the profile is default for the location."""

    LOCATION_DEFAULT = "LocationDefault"
    CUSTOM = "Custom"


class AppProtocol(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Tells Dapr which protocol your application is using. Valid options are http and grpc. Default
    is http.
    """

    HTTP = "http"
    GRPC = "grpc"


class BindingType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Custom Domain binding type."""

    DISABLED = "Disabled"
    SNI_ENABLED = "SniEnabled"


class CertificateProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Provisioning state of the certificate."""

    SUCCEEDED = "Succeeded"
    FAILED = "Failed"
    CANCELED = "Canceled"
    DELETE_FAILED = "DeleteFailed"
    PENDING = "Pending"


class CheckNameAvailabilityReason(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The reason why the given name is not available."""

    INVALID = "Invalid"
    ALREADY_EXISTS = "AlreadyExists"


class ConnectedEnvironmentProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Provisioning state of the Kubernetes Environment."""

    SUCCEEDED = "Succeeded"
    FAILED = "Failed"
    CANCELED = "Canceled"
    WAITING = "Waiting"
    INITIALIZATION_IN_PROGRESS = "InitializationInProgress"
    INFRASTRUCTURE_SETUP_IN_PROGRESS = "InfrastructureSetupInProgress"
    INFRASTRUCTURE_SETUP_COMPLETE = "InfrastructureSetupComplete"
    SCHEDULED_FOR_DELETE = "ScheduledForDelete"


class ContainerAppProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Provisioning state of the Container App."""

    IN_PROGRESS = "InProgress"
    SUCCEEDED = "Succeeded"
    FAILED = "Failed"
    CANCELED = "Canceled"
    DELETING = "Deleting"


class CookieExpirationConvention(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The convention used when determining the session cookie's expiration."""

    FIXED_TIME = "FixedTime"
    IDENTITY_PROVIDER_DERIVED = "IdentityProviderDerived"


class CreatedByType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The type of identity that created the resource."""

    USER = "User"
    APPLICATION = "Application"
    MANAGED_IDENTITY = "ManagedIdentity"
    KEY = "Key"


class DnsVerificationTestResult(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """DNS verification test result."""

    PASSED = "Passed"
    FAILED = "Failed"
    SKIPPED = "Skipped"


class EnvironmentProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Provisioning state of the Environment."""

    SUCCEEDED = "Succeeded"
    FAILED = "Failed"
    CANCELED = "Canceled"
    WAITING = "Waiting"
    INITIALIZATION_IN_PROGRESS = "InitializationInProgress"
    INFRASTRUCTURE_SETUP_IN_PROGRESS = "InfrastructureSetupInProgress"
    INFRASTRUCTURE_SETUP_COMPLETE = "InfrastructureSetupComplete"
    SCHEDULED_FOR_DELETE = "ScheduledForDelete"
    UPGRADE_REQUESTED = "UpgradeRequested"
    UPGRADE_FAILED = "UpgradeFailed"


class ExtendedLocationTypes(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The type of extendedLocation."""

    CUSTOM_LOCATION = "CustomLocation"


class ForwardProxyConvention(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The convention used to determine the url of the request made."""

    NO_PROXY = "NoProxy"
    STANDARD = "Standard"
    CUSTOM = "Custom"


class IngressClientCertificateMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Client certificate mode for mTLS authentication. Ignore indicates server drops client
    certificate on forwarding. Accept indicates server forwards client certificate but does not
    require a client certificate. Require indicates server requires a client certificate.
    """

    IGNORE = "ignore"
    ACCEPT = "accept"
    REQUIRE = "require"


class IngressTransportMethod(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Ingress transport protocol."""

    AUTO = "auto"
    HTTP = "http"
    HTTP2 = "http2"
    TCP = "tcp"


class JobExecutionRunningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Current running State of the job."""

    RUNNING = "Running"
    PROCESSING = "Processing"
    STOPPED = "Stopped"
    DEGRADED = "Degraded"
    FAILED = "Failed"
    UNKNOWN = "Unknown"
    SUCCEEDED = "Succeeded"


class JobProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Provisioning state of the Container Apps Job."""

    IN_PROGRESS = "InProgress"
    SUCCEEDED = "Succeeded"
    FAILED = "Failed"
    CANCELED = "Canceled"
    DELETING = "Deleting"


class LogLevel(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Sets the log level for the Dapr sidecar. Allowed values are debug, info, warn, error. Default
    is info.
    """

    INFO = "info"
    DEBUG = "debug"
    WARN = "warn"
    ERROR = "error"


class ManagedCertificateDomainControlValidation(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Selected type of domain control validation for managed certificates."""

    CNAME = "CNAME"
    HTTP = "HTTP"
    TXT = "TXT"


class ManagedServiceIdentityType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of managed service identity (where both SystemAssigned and UserAssigned types are
    allowed).
    """

    NONE = "None"
    SYSTEM_ASSIGNED = "SystemAssigned"
    USER_ASSIGNED = "UserAssigned"
    SYSTEM_ASSIGNED_USER_ASSIGNED = "SystemAssigned,UserAssigned"


class RevisionHealthState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Current health State of the revision."""

    HEALTHY = "Healthy"
    UNHEALTHY = "Unhealthy"
    NONE = "None"


class RevisionProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Current provisioning State of the revision."""

    PROVISIONING = "Provisioning"
    PROVISIONED = "Provisioned"
    FAILED = "Failed"
    DEPROVISIONING = "Deprovisioning"
    DEPROVISIONED = "Deprovisioned"


class Scheme(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Scheme to use for connecting to the host. Defaults to HTTP."""

    HTTP = "HTTP"
    HTTPS = "HTTPS"


class SourceControlOperationState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Current provisioning State of the operation."""

    IN_PROGRESS = "InProgress"
    SUCCEEDED = "Succeeded"
    FAILED = "Failed"
    CANCELED = "Canceled"


class StorageType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Storage type for the volume. If not provided, use EmptyDir."""

    AZURE_FILE = "AzureFile"
    EMPTY_DIR = "EmptyDir"
    SECRET = "Secret"


class TriggerType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Trigger type of the job."""

    SCHEDULED = "Scheduled"
    EVENT = "Event"
    MANUAL = "Manual"


class Type(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The type of probe."""

    LIVENESS = "Liveness"
    READINESS = "Readiness"
    STARTUP = "Startup"


class UnauthenticatedClientActionV2(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The action to take when an unauthenticated client attempts to access the app."""

    REDIRECT_TO_LOGIN_PAGE = "RedirectToLoginPage"
    ALLOW_ANONYMOUS = "AllowAnonymous"
    RETURN401 = "Return401"
    RETURN403 = "Return403"



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

import azure.cli.core.azclierror


def bot_exception_handler(ex):
    from azure.core.exceptions import HttpResponseError
    from msrestazure.azure_exceptions import CloudError
    from msrest.exceptions import ClientRequestError  # pylint: disable=import-error
    if isinstance(ex, HttpResponseError):
        message = 'An error occurred. {0}: {1}'.format(
            ex.error.code,
            ex.error.message
        )
        raise azure.cli.core.azclierror.AzureResponseError(message)
    if isinstance(ex, CloudError) and ex.status_code == 404:
        return None
    if isinstance(ex, ClientRequestError):
        message = 'Error occurred in sending request. Please file an issue on {0}'.format(
            'https://github.com/microsoft/botframework-sdk'
        )
        raise azure.cli.core.azclierror.ClientRequestError(message)
    message = 'Unknown error during execution. Please file an issue on {0}'.format(
        'https://github.com/microsoft/botframework-sdk'
    )
    raise azure.cli.core.azclierror.AzCLIError(message)
